package com.ruoyi.web.controller.pc;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.domain.resp.THospitalPageResp;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.THospital;
import com.ruoyi.system.service.ITHospitalService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 医院信息Controller
 * 
 * @author ruoyi
 * @date 2022-08-03
 */
@Api("pc-医院列表")
@RestController
@RequestMapping("/system/hospital")
public class THospitalController extends BaseController
{
    @Autowired
    private ITHospitalService tHospitalService;

    /**
     * 查询医院信息列表
     */
    @ApiOperation("查询医院信息列表")
    @PostMapping("/list")
    public TableDataInfo list(@RequestBody THospital tHospital)
    {
        startPage();
        List<THospitalPageResp> list = tHospitalService.queryByPage(tHospital);
        return getDataTable(list);
    }

    /**
     * 导出医院信息列表
     */
    @Log(title = "医院信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, THospital tHospital)
    {
        List<THospital> list = tHospitalService.selectTHospitalList(tHospital);
        ExcelUtil<THospital> util = new ExcelUtil<THospital>(THospital.class);
        util.exportExcel(response, list, "医院信息数据");
    }

    /**
     * 获取医院信息详细信息
     */
    @ApiOperation("获取医院信息详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tHospitalService.selectTHospitalById(id));
    }

    /**
     * 新增医院信息
     */
    @ApiOperation("新增医院信息")
    @Log(title = "医院信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody THospital tHospital)
    {
        return toAjax(tHospitalService.insertTHospital(tHospital));
    }

    /**
     * 修改医院信息
     */
    @ApiOperation("修改医院信息")
    @Log(title = "医院信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody THospital tHospital)
    {
        return toAjax(tHospitalService.updateTHospital(tHospital));
    }

    /**
     * 删除医院信息
     */
    @ApiOperation("删除医院信息")
    @Log(title = "医院信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tHospitalService.deleteTHospitalByIds(ids));
    }

    /**
     * 获取管理员下拉接口
     */
    @ApiOperation("获取医院管理员下拉接口")
    @GetMapping(value = "/getHosptialAdminList")
    public AjaxResult getHosptialAdminList()
    {
        return AjaxResult.success(tHospitalService.getHosptialAdminList());
    }
}
